<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko_KR" sourcelanguage="en_US">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>클릭하면 응용 프로그램으로 복귀합니다</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>정리</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 항목</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>양식</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>파일명</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>재시도</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>중지</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>YouTube에 팟캐스트 게시</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>제목</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>설명</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>저자</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>보드</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>웹</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>문서</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>스타일러스</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>배경</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>배경 바꾸기</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>실행 취소</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>다시 실행</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>이전 페이지</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>다음 페이지</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>문서 관리</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>웹 검색</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>줄</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>작은 줄</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>중간 줄</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>큰 줄</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>종료</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>지우개</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">작은 지우개</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>중간 지우개</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>큰 지우개</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">색상</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>뒤로</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>왼쪽</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>앞으로</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>오른쪽</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>다시보기</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>현재 페이지 다시보기</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>홈</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>홈페이지 불러오기</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>북마크</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>북마크 보이기</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>북마크</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>북마크 추가</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>보드 표시</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>지우기</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>콘텐츠 지우기</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>기본 설정</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>디스플레이 기본 설정</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>라이브러리</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>라이브러리 보이기</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>바탕 화면 보이기</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>컴퓨터 바탕 화면 보이기</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>크게</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>확대</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>작게</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>축소</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>새 폴더</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>새 폴더 만들기</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>새 문서</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>새 문서 만들기</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>가져오기</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>문서 가져오기</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>내보내기</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>문서 내보내기</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>보드에서 열기</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>보드에서 페이지 열기</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>복제</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>선택된 콘텐츠 복제</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>선택된 콘텐츠 삭제</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>작업 문서에 추가</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>열린 문서에 선택된 콘텐츠 추가</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>추가</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>문서에 콘텐츠 추가</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>이름 바꾸기</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>콘텐츠 이름 바꾸기</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>도구</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>도구 표시</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>다중 화면</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>와이드 크기 (16/9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>와이드 크기 문서 사용 (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>일반 크기 (4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>일반 크기 문서 사용 (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>사용자 정의 크기</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>사용자 정의 크기 문서 사용</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>불러오기 중지</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>웹 페이지 불러오기 중지</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>잘라내기</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사하기</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>붙여넣기</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>대기모드</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>프레젠테이션 대기모드 전환</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>가상 키보드</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>가상 키보드 표시</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>밝은 단색 배경</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>밝은 색</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>밝은 체크무늬 배경</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>어두운 단색 배경</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>어두운 색</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>어두운 체크무늬 배경</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>팟캐스트</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>프레젠테이션을 동영상으로 레코딩</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>레코딩</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>화면 레코딩 시작</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>항목 지우기</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>모든 항목 지우기</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>주석 지우기</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>모든 주석 지우기</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>페이지 지우기</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>모든 요소 지우기</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>펜</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>문서에 주석 달기</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>주석 지우기</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>마커</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>강조</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>선택자</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>객체 선택 및 수정</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>손</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>페이지 스크롤</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>레이저 포인터</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>가상 레이저 포인터</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>줄 그리기</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>텍스트</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>텍스트 쓰기</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>캡처</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>화면 일부 캡처</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>현재 페이지에 추가</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>현재 페이지에 항목 추가</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>새 페이지에 추가</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>새 페이지에 항목 추가</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>라이브러리에 추가</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>라이브러리에 항목 추가</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>페이지</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>새 페이지 만들기</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>새 페이지</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>페이지 복제</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>현재 페이지 복제</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>페이지 가져오기</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>외부 페이지 가져오기</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>일시 중지</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>팟캐스트 레코딩 일시 중지</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>팟캐스트 설정</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>팟캐스트 레코딩 설정</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>플래시 트랩</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>플래시 콘텐츠 트랩</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>웹 트랩</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>웹 콘텐츠 트랩</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>사용자 정의 캡처</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>창 캡처</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>창 캡처하기</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>웹 콘텐츠 포함</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>포함 가능한 웹 콘텐츠 캡처</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>디스플레이에 보이기</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>디스플레이 화면에 메인 화면 보이기</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>모든 주석 지우기</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>eduMedia 시뮬레이션 가져오기</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>업데이트 확인</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation type="unfinished">OpenBoard 종료</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation type="unfinished">OpenBoard 숨기기</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation type="unfinished">OpenBoard 응용 프로그램 숨기기</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">재생</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation type="unfinished">항목과 상호 작용</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation type="unfinished">배경 지우기</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation type="unfinished">배경 제거</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>인증이 필요합니다</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>사용자명:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>암호:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>프록시 인증</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>프록시에 연결</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>사용자명:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>암호:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>향후 사용을 위해 사용자명과 암호 저장</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation type="unfinished">요소 ID = </translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation type="unfinished">대상 형식으로 지원되지 않는 콘텐츠입니다.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="unfinished">페이지 제거</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation type="unfinished">선택한 문서 &apos;%0&apos;에서 1페이지를 제거하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>페이지 크기</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>팟캐스트</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>웹</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>새로운 업데이트가 있습니다. 웹 페이지로 이동하시겠습니까?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>업데이트가 없습니다</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>새 업데이트가 있습니다</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>업데이트</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>%1 콘텐츠 다운로드 실패</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>다운로드 완료</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>알 수 없는 도구 유형 %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>알 수 없는 콘텐츠 유형 %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>항목 추가</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>모든 지원 형식 (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="obsolete">문서에서 %1페이지 삭제</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation type="unfinished">%1페이지 삭제됨</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation type="unfinished">파일 추가 작업 실패: 파일을 복사하는 도중 오류 발생</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished">그룹화</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation type="unfinished">그룹 해제</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">색상</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>이미지를 라이브러리에 추가하는 도중 오류가 발생했습니다</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation type="unfinished">캡처한 이미지</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>캐시 속성</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>색상:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>모양:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>화면 일부 캡처</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>화면 캡처</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>스타일러스 팔레트 보이기</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>보조 화면에 보드 보이기</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>보조 화면에 바탕 화면 보이기</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>새 폴더</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>%1 페이지</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>이미지 폴더 추가</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>이미지 추가</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>파일에서 페이지 추가</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>%1 문서 복제 중</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>%1 문서 복사됨</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">페이지 제거</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">문서 제거</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">정말로 &apos;%1&apos; 문서를 제거하시겠습니까?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">휴지통 비우기</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">정말로 휴지통을 비우시겠습니까?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">휴지통 비우는 중</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">휴지통 비우기 완료</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">폴더 제거</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">정말로 &apos;%1&apos; 폴더와 해당 내용을 모두 제거하시겠습니까?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">선택된 문서가 없습니다!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>지원되는 파일 열기</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>%1 파일 가져오는 중...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>파일 가져오기 실패 ...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>폴더에서 모든 이미지 가져오기</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>비우기</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>휴지통</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>문서 열기</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>문서에 모든 이미지 추가</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>모든 이미지 (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>선택된 영역에 이미지 파일이 없습니다!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="obsolete">
            <numerusform>선택한 문서 &apos;%1&apos;에서 %n페이지를 제거하시겠습니까?</numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation type="unfinished">폴더에 이미지 파일이 없습니다</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation type="unfinished">무제 문서</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>이미지</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>동영상</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>객체</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>위젯</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>지원되는 모든 파일 (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>%1 파일 저장됨</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation type="unfinished">%1/%2페이지 삽입 중</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation type="unfinished">가져오기 완료.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation type="unfinished">%1 파일 가져오기 완료.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation type="unfinished">%1 파일 가져오는 중</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>%0 페이지</translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">내보내기 실패.</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">적용</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">취소</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">휴지통</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform variants="yes">
                <lengthvariant>%1 페이지 복사됨</lengthvariant>
                <lengthvariant></lengthvariant>
            </numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform variants="yes">
                <lengthvariant>%1 페이지 복사됨</lengthvariant>
                <lengthvariant></lengthvariant>
            </numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">%1/%2 페이지 복사 중</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (사본)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">%1/%2 페이지 복사 중</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="obsolete">
            <numerusform variants="yes">
                <lengthvariant>%1 페이지 복사됨</lengthvariant>
                <lengthvariant></lengthvariant>
            </numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation type="unfinished">파일 다운로드 중</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">취소</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">%0 페이지</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">%0 페이지</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation type="unfinished">내보내는 도중 경고가 나타났습니다</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">문서를 내보내는 중...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">내보내기 완료.</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation type="unfinished">IWB로 내보내기</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation type="unfinished">IWB 파일로 내보내기</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">문서를 내보내는 중...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">내보내기 완료.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished">내보내기 실패.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>페이지</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>UBZ 파일로 내보내기</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">문서를 내보내는 중...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">내보내기 완료.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>%1 내보내는 중 %2/%3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">문서를 내보내는 중...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">내보내기 완료.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished">내보내기 실패.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>PDF 파일로 내보내기</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">문서를 내보내는 중...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">내보내기 완료.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>PDF로 내보내기</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>PDF 파일로 내보내기</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">문서를 내보내는 중...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">내보내기 완료.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>%1/%2 페이지 내보내는 중</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>PDF로 내보내기</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>페이지</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>웹 데이터로 내보내기</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>문서를 내보내는 중...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>내보내기 완료.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>내보내기 실패.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>웹 브라우저로 내보내기</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation type="unfinished">페이지에 추가</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="obsolete">배경으로 지정</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation type="unfinished">라이브러리에 추가</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation type="unfinished">객체 정보</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation type="unfinished">즐겨찾기에 추가</translation>
    </message>
    <message>
        <source>Share</source>
        <translation type="unfinished">공유</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished">검색</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">삭제</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation type="unfinished">폴더로 돌아가기</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation type="unfinished">즐겨찾기에서 제거</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation type="unfinished">새 폴더 만들기</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation type="unfinished">파일 시스템 다시 스캔</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation type="unfinished">가져온 이미지</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation type="unfinished">오디오</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation type="unfinished">동영상</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished">사진</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="obsolete">애니메이션</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation type="unfinished">대화형 작업</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation type="unfinished">응용 프로그램</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation type="unfinished">도형</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation type="unfinished">즐겨찾기</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation type="unfinished">웹 검색</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation type="unfinished">휴지통</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">적용</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">취소</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation type="unfinished">새 폴더 이름 입력</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation type="unfinished">불러오는 중</translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation type="unfinished">잠김</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation type="unfinished">확장 화면에 보이기</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>잠김</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>확장 화면에 보이기</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>콘텐츠 소스로 이동</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">배경으로 지정</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;이곳에 텍스트를 입력하십시오&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>텍스트 색상</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation type="unfinished">편집 가능</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation type="unfinished">웹</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation type="unfinished">불러오는 중 ...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>동결됨</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>도구로 변환</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>일반 파일 형식 (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>%1 파일 가져오는 중...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>%1 파일 가져오기 실패.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>가져오기 완료.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>가져오기 실패.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>%1 파일 가져오는 중...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>가져오기 완료.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>%1 파일 가져오기 실패.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>이미지 형식 (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>PDF 가져오기 실패.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>%1/%2 페이지 가져오는 중</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>동영상을 인트라넷에 게시하는 도중 오류가 발생했습니다 (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>인트라넷 게시 진행 중 %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>게시</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation type="unfinished">입력</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>예</translation>
    </message>
    <message>
        <source>No</source>
        <translation>아니요</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">닫기</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;%2에 &quot;%1&quot;의 사용자명과 암호를 입력하십시오&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>프록시 연결 실패</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>SSL 오류:

%1

%2

해당 호스트에 대해 이 오류들을 무시하시겠습니까?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>예</translation>
    </message>
    <message>
        <source>No</source>
        <translation>아니요</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">취소</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(사본)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>문서 저장소 손실</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation type="unfinished">영어</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation type="unfinished">러시아어</translation>
    </message>
    <message>
        <source>German</source>
        <translation type="unfinished">독일어</translation>
    </message>
    <message>
        <source>French</source>
        <translation type="unfinished">프랑스어</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation type="unfinished">스위스 프랑스어</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>인코더 실행 실패 ...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>사용 가능한 팟캐스트 인코더가 없습니다 ...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>%1 파트</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation type="unfinished">바탕 화면에 ...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>%1 폴더에</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>%1 팟캐스트가 생성되었습니다</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>팟캐스트 레코딩 오류 (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>기본 오디오 입력</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>오디오 레코딩 없음</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>작게</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>중간</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>전체</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>인트라넷에 게시</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>YouTube에 게시</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation type="unfinished">버전: </translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>마커는 압력 감지식입니다</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">프록시 로그인</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">사용자명:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">암호:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">웹에 문서 게시</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">제목:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">설명:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">게시</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>내 동영상</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation type="unfinished">미리보기 썸네일 생성 중 ...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 썸네일 생성됨 ...</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">%0 페이지</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>마스크</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>눈금자</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>나침반</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>각도기</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>삼각자</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>돋보기</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>캐시</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>전체 페이지</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>웹</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>문서 업데이터</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>파일 업데이트가 필요합니다.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation type="unfinished">백업 경로: </translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>찾아보기</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>업데이트</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>백업 폴더를 선택하십시오</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>파일 업데이트가 완료되었습니다!
업데이트된 문서에 액세스하려면 응용 프로그램을 재시작하십시오.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>업데이트 도중 오류가 발생했습니다. 파일은 영향 받지 않았습니다.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>파일 업데이트 결과</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>파일 업데이트 중</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>잠시 후 가져오기가 시작됩니다...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="unfinished">나중에 알림</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>불러오는 중...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 호출됨 (메소드=%1, 상태=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>YouTube 인증 실패.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>동영상을 YouTube에 업로드하는 도중 오류가 발생했습니다 (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>YouTube 업로드 진행 중 %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>업로드</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>자동차 &amp; 차량</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>음악</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>애완동물 &amp; 동물</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>스포츠</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>여행 &amp; 이벤트</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>게임</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>코미디</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>사람 &amp; 블로그</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>뉴스 &amp; 정치</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>오락</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>교육</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>요령 &amp; 스타일</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>비영리 &amp; 운동</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>과학 &amp; 기술</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>지우기</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>파일 저장</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>다운로드 취소됨: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>저장된 파일 열기 오류: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>저장 오류: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>네트워크 오류: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>초</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>분</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 남았습니다</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1/%2 (%3/초) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1/%2 - 중지됨</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>바이트</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 다운로드</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 다운로드</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>제목</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>주소</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>오늘 이전 시간</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 항목</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>검색</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>새 탭(&amp;T)</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>탭 복제</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>탭 닫기(&amp;C)</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>다른 탭 닫기(&amp;O)</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>탭 다시보기</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>모든 탭 다시보기</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>최근 닫은 탭</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(무제)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>검색</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>최근 검색 없음</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>최근 검색</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>최근 검색 지우기</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>현재 문서에 추가</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>페이지 불러오기 오류: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>새 탭에서 열기</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>YouTube에 팟캐스트 게시</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>제목</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>설명</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>키워드</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>범주</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>YouTube 사용자명</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>YouTube 암호</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;귀하는 &apos;Upload&apos;를 클릭함으로써 귀하가 해당 콘텐츠에 대한 모든 권한을 소유하거나 소유자로부터 해당 콘텐츠를 YouTube에 공개할 수 있도록 허락받았으며, 해당 콘텐츠가 YouTube 이용약관 (&lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;)을 준수함을 보증합니다.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">OpenBoard</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>밝은 배경</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>어두운 배경</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>불투명도</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>줄 너비</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>중간</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>강렬한</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>가는</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>펜은 압력 감지식입니다</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>대화</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>제목</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>이메일</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>저자</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>설명</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">대화</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">제목</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">이메일</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">저자</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">설명</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>기본 설정</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>버전 : …</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>기본 설정</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>디스플레이</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>인터넷</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>외부 브라우저에 페이지 보이기</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>홈페이지:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>가상 키보드</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">키보드 버튼 크기:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>툴바</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>상단에 위치 (타블렛 권장사항)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>하단에 위치 (화이트보드 권장사항)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>버튼 아래에 텍스트 표시</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>스타일러스 팔레트</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>가로</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>세로</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>펜</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>마커</translation>
    </message>
    <message>
        <source>About</source>
        <translation>소개</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>소프트웨어 업데이트</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>실행시 소프트웨어 업데이트 확인</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>라이선스</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>네트워크</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation type="unfinished">보조 화면 또는 프로젝터에 내부 웹 페이지 콘텐츠 표시</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation type="unfinished">다중 디스플레이</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation type="unfinished">컨트롤 디스플레이 스왑 및 디스플레이 보기</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation type="unfinished">모드</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation type="unfinished">시작할 모드:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation type="unfinished">보드</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="unfinished">바탕 화면</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation type="unfinished">프록시 사용자:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation type="unfinished">패스:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation type="unfinished">Credits</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">어두운 배경</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">불투명도</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">밝은 배경</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>플래시 트랩</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>플래시를 트랩으로 저장</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>응용 프로그램 이름</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>응용 프로그램 만들기</translation>
    </message>
</context>
</TS>
